@@ -57,6 +57,9 @@ _validator_opts = [
 ]
 
 
+KNOWN_BAD_GROUPS = ['keystone_authtoken']
+
+
 def _register_cli_opts(conf):
     """Register the formatter's CLI options with a ConfigOpts instance.
 
@@ -85,17 +88,21 @@ def _validate_opt(group, option, opt_data):
     return option in name_data
 
 
+def load_opt_data(conf):
+    with open(conf.opt_data) as f:
+        return yaml.safe_load(f)
+
+
 def _validate(conf):
     conf.register_opts(_validator_opts)
     if conf.namespace:
         groups = generator._get_groups(generator._list_opts(conf.namespace))
         opt_data = generator._generate_machine_readable_data(groups, conf)
     elif conf.opt_data:
-        with open(conf.opt_data) as f:
-            opt_data = yaml.safe_load(f)
+        opt_data = load_opt_data(conf)
     else:
         # TODO(bnemec): Implement this logic with group?
-        raise RuntimeError('Neither namespace or opt-data provided.')
+        raise RuntimeError('Neither namespace nor opt-data provided.')
     sections = {}
     parser = cfg.ConfigParser(conf.input_file, sections)
     parser.parse()
@@ -109,6 +116,13 @@ def _validate(conf):
                 logging.warn('Deprecated opt %s/%s found', section, option)
                 warnings = True
             elif not _validate_opt(section, option, opt_data):
+                if section in KNOWN_BAD_GROUPS:
+                    logging.info('Ignoring missing option "%s" from group '
+                                 '"%s" because the group is known to have '
+                                 'incomplete sample config data and thus '
+                                 'cannot be validated properly.',
+                                 option, section)
+                    continue
                 logging.error('%s/%s not found', section, option)
                 errors = True
     if errors or (warnings and conf.fatal_warnings):
@@ -119,7 +133,7 @@ def _validate(conf):
 def main():
     """The main function of oslo-config-validator."""
     version = pkg_resources.get_distribution('oslo.config').version
-    logging.basicConfig(level=logging.WARN)
+    logging.basicConfig(level=logging.INFO)
     conf = cfg.ConfigOpts()
     _register_cli_opts(conf)
     try:
